@@ -16,13 +16,13 @@ use Date::Calc qw( Today Add_Delta_Days );
 use DBI;
 use strict;
 
-use example::BookStore::Object;
-use example::BookStore::Book;
-use example::BookStore::Author;
-use example::BookStore::Publisher;
-use example::BookStore::Order;
-use example::BookStore::BooksOrdered;
-use example::BookStore::Test1;
+use test::BookStore::Object;
+use test::BookStore::Book;
+use test::BookStore::Author;
+use test::BookStore::Publisher;
+use test::BookStore::Order;
+use test::BookStore::BooksOrdered;
+use test::BookStore::Test1;
 
 use Data::Dumper;
 
@@ -62,7 +62,7 @@ sub startup : Test(startup)
 	my $self = shift;
 
 	# convenience
-	$self->{database} = $example::BookStore::Object::DATABASE;
+	$self->{database} = $test::BookStore::Object::DATABASE;
 }
 
 sub setup : Test(setup)
@@ -171,9 +171,9 @@ sub objectCriteria1 : Test(2)
 {
 	my $self = shift;
 
-	my $author = example::BookStore::Author->load({ author_id => 1 });
+	my $author = test::BookStore::Author->load({ author_id => 1 });
 	my $criteria = Xmldoom::Criteria->new({ parent => $author });
-	my @books = example::BookStore::Book->Search( $criteria );
+	my @books = test::BookStore::Book->Search( $criteria );
 
 	is( scalar @books, 1 );
 	is( $books[0]->_get_attr( 'title' ), "My Science Fiction Autobiography" );
@@ -183,10 +183,10 @@ sub objectCriteria2 : Test(1)
 {
 	my $self = shift;
 
-	my $author = example::BookStore::Author->load({ author_id => 2 });
+	my $author = test::BookStore::Author->load({ author_id => 2 });
 	my $criteria = Xmldoom::Criteria->new();
 	$criteria->add( 'Book/author', $author );
-	my @books = example::BookStore::Book->Search( $criteria );
+	my @books = test::BookStore::Book->Search( $criteria );
 
 	is ( scalar @books, 5 );
 }
@@ -195,13 +195,13 @@ sub objectCriteria3 : Test(1)
 {
 	my $self = shift;
 
-	my $author = example::BookStore::Author->load({ author_id => 2 });
+	my $author = test::BookStore::Author->load({ author_id => 2 });
 	my $criteria = Xmldoom::Criteria->new();
 	$criteria->join_prop( 'Author/book', 'Publisher/book' );
 
 	try eval
 	{
-		example::BookStore::Book->Search( $criteria );
+		test::BookStore::Book->Search( $criteria );
 	};
 
 	# TODO: This should be a specific "Cannot Join" exception.
@@ -213,11 +213,11 @@ sub objectCriteriaAttrs1 : Test(1)
 {
 	my $self = shift;
 
-	my $author   = example::BookStore::Author->load({ author_id => 1 });
+	my $author   = test::BookStore::Author->load({ author_id => 1 });
 	my $criteria = Xmldoom::Criteria->new();
 	$criteria->add( "Book/author", $author );
 
-	my @list = example::BookStore::Book->SearchAttrs( $criteria, "title" );
+	my @list = test::BookStore::Book->SearchAttrs( $criteria, "title" );
 
 	is( $list[0]->{title}, "My Science Fiction Autobiography" );
 }
@@ -228,7 +228,7 @@ sub objectCriteriaDistinctAttrs1 : Test(4)
 
 	my $criteria = Xmldoom::Criteria->new();
 
-	my @list = example::BookStore::Author->SearchDistinctAttrs( $criteria, "first_name" );
+	my @list = test::BookStore::Author->SearchDistinctAttrs( $criteria, "first_name" );
 
 	is( $list[0]->{first_name}, "Russell A" );
 	is( $list[1]->{first_name}, "Douglas N" );
@@ -243,7 +243,7 @@ sub databaseCriteria1 : Test(1)
 	my $criteria = Xmldoom::Criteria->new();
 	$criteria->add_attr( "book/author_id", 1 );
 
-	my @list = $example::BookStore::Object::DATABASE->Search( $criteria, "book/title" );
+	my @list = $test::BookStore::Object::DATABASE->Search( $criteria, "book/title" );
 
 	is ( $list[0]->{title}, "My Science Fiction Autobiography" );
 }
@@ -252,7 +252,7 @@ sub objectPropsSimple1 : Test(2)
 {
 	my $self = shift;
 
-	my $author = example::BookStore::Author->load({ author_id => 1 });
+	my $author = test::BookStore::Author->load({ author_id => 1 });
 
 	is( $author->get_first_name(), 'Russell A' );
 	is( $author->get_last_name(),  'Snopek' );
@@ -262,7 +262,7 @@ sub objectPropsObjectGet1 : Test(1)
 {
 	my $self = shift;
 
-	my $book = example::BookStore::Book->load({ book_id => 1 });
+	my $book = test::BookStore::Book->load({ book_id => 1 });
 	my $publisher = $book->get_publisher();
 
 	is( $publisher->get_name(), "Lulu Press" );
@@ -272,7 +272,7 @@ sub objectPropsObjectGet2 : Test(4)
 {
 	my $self = shift;
 
-	my $publisher = example::BookStore::Publisher->load({ publisher_id => 3 });
+	my $publisher = test::BookStore::Publisher->load({ publisher_id => 3 });
 	my $books = $publisher->get_books();
 
 	is( $books->[0]->get_title(), "The Restaurant at the End of the Universe" );
@@ -285,7 +285,7 @@ sub objectPropsObjectGet3 : Test(2)
 {
 	my $self = shift;
 
-	my $publisher = example::BookStore::Publisher->load({ publisher_id => 3 });
+	my $publisher = test::BookStore::Publisher->load({ publisher_id => 3 });
 	my $books = $publisher->get_books({ title => 'Mostly Harmless' });
 
 	is ( scalar @$books, 1 );
@@ -296,8 +296,8 @@ sub objectPropsObjectSet1 : Test(1)
 {
 	my $self = shift;
 
-	my $book = example::BookStore::Book->load({ book_id => 2 });
-	my $publisher = example::BookStore::Publisher->load({ publisher_id => 3 });
+	my $book = test::BookStore::Book->load({ book_id => 2 });
+	my $publisher = test::BookStore::Publisher->load({ publisher_id => 3 });
 
 	$book->set_publisher( $publisher );
 
@@ -308,9 +308,9 @@ sub objectPropsObjectCreate1 : Test(5)
 {
 	my $self = shift;
 
-	my $publisher = example::BookStore::Publisher->load({ publisher_id => 4 });
-	my $author = example::BookStore::Author->load({ author_id => 2 });
-	my $book = example::BookStore::Book->new();
+	my $publisher = test::BookStore::Publisher->load({ publisher_id => 4 });
+	my $author = test::BookStore::Author->load({ author_id => 2 });
+	my $book = test::BookStore::Book->new();
 
 	$book->set_title     ( 'Long Dark Tea Time of the Soul' );
 	$book->set_isbn      ( '0671742515' );
@@ -322,7 +322,7 @@ sub objectPropsObjectCreate1 : Test(5)
 	is( $book->_get_attr( 'book_id' ), 7 );
 
 	# re-load book
-	$book = example::BookStore::Book->load({ book_id => 7 });
+	$book = test::BookStore::Book->load({ book_id => 7 });
 	is( $book->get_title(), 'Long Dark Tea Time of the Soul' );
 	is( $book->get_isbn(),  '0671742515' );
 	is( $book->get_author()->get_last_name(), 'Adams' );
@@ -333,9 +333,9 @@ sub objectPropsObjectCreate2 : Test(5)
 {
 	my $self = shift;
 
-	my $publisher = example::BookStore::Publisher->load({ publisher_id => 4 });
-	my $author = example::BookStore::Author->load({ author_id => 2 });
-	my $book = example::BookStore::Book->new({
+	my $publisher = test::BookStore::Publisher->load({ publisher_id => 4 });
+	my $author = test::BookStore::Author->load({ author_id => 2 });
+	my $book = test::BookStore::Book->new({
 		title     => 'Long Dark Tea Time of the Soul',
 		isbn      => '0671742515',
 		author    => $author,
@@ -347,7 +347,7 @@ sub objectPropsObjectCreate2 : Test(5)
 	is( $book->_get_attr( 'book_id' ), 7 ) || return;
 
 	# re-load book
-	$book = example::BookStore::Book->load({ book_id => 7 });
+	$book = test::BookStore::Book->load({ book_id => 7 });
 	is( $book->get_title(), 'Long Dark Tea Time of the Soul' );
 	is( $book->get_isbn(),  '0671742515' );
 	is( $book->get_author()->get_last_name(), 'Adams' );
@@ -358,8 +358,8 @@ sub objectPropsObjectAdd1 : Test(5)
 {
 	my $self = shift;
 
-	my $publisher = example::BookStore::Publisher->load({ publisher_id => 4 });
-	my $author = example::BookStore::Author->load({ author_id => 2 });
+	my $publisher = test::BookStore::Publisher->load({ publisher_id => 4 });
+	my $author = test::BookStore::Author->load({ author_id => 2 });
 
 	my $book = $author->add_book({
 		title     => 'Long Dark Tea Time of the Soul',
@@ -371,7 +371,7 @@ sub objectPropsObjectAdd1 : Test(5)
 	is( $book->_get_attr( 'book_id' ), 7 ) || return;
 
 	# re-load book
-	$book = example::BookStore::Book->load({ book_id => 7 });
+	$book = test::BookStore::Book->load({ book_id => 7 });
 	is( $book->get_title(), 'Long Dark Tea Time of the Soul' );
 	is( $book->get_isbn(),  '0671742515' );
 	is( $book->get_author()->get_last_name(), 'Adams' );
@@ -384,13 +384,13 @@ sub objectDelete1 : Test(1)
 {
 	my $self = shift;
 
-	my $book = example::BookStore::Book->load({ book_id => 1 });
+	my $book = test::BookStore::Book->load({ book_id => 1 });
 	$book->delete();
 
 	try eval
 	{
 		# attempt to reload
-		example::BookStore::Book->load({ book_id => 1 });
+		test::BookStore::Book->load({ book_id => 1 });
 	};
 
 	my $error = catch;
@@ -402,7 +402,7 @@ sub objectChildParent1 : Test(2)
 {
 	my $self = shift;
 
-	my $book = example::BookStore::Book->load({ book_id => 1 });
+	my $book = test::BookStore::Book->load({ book_id => 1 });
 	my $publisher = $book->get_publisher();
 
 	is( $publisher->{parent}, $book );
@@ -418,9 +418,9 @@ sub objectChildParent2 : Test(2)
 {
 	my $self = shift;
 
-	my $publisher = example::BookStore::Publisher->load({ publisher_id => 3 });
+	my $publisher = test::BookStore::Publisher->load({ publisher_id => 3 });
 	my $criteria  = Xmldoom::Criteria->new( $publisher );
-	my @books     = example::BookStore::Book->Search( $criteria );
+	my @books     = test::BookStore::Book->Search( $criteria );
 
 	is( $books[0]->{parent}, $publisher );
 
@@ -428,7 +428,7 @@ sub objectChildParent2 : Test(2)
 	$publisher->save();
 
 	# reload
-	@books = example::BookStore::Book->Search( $criteria );
+	@books = test::BookStore::Book->Search( $criteria );
 	is( $books[0]->get_title(), 'Blah' );
 }
 
@@ -436,8 +436,8 @@ sub objectChildParent3 : Test(1)
 {
 	my $self = shift;
 
-	my $publisher = example::BookStore::Publisher->new({ name => "My Publisher" });
-	my $author    = example::BookStore::Author->load({ author_id => 3 });
+	my $publisher = test::BookStore::Publisher->new({ name => "My Publisher" });
+	my $author    = test::BookStore::Author->load({ author_id => 3 });
 	my $book      = $publisher->add_book({ author => $author, title => "My Book", isbn => "XYZ" });
 
 	$publisher->save();
@@ -450,8 +450,8 @@ sub objectChildParent4 : Test(2)
 {
 	my $self = shift;
 
-	my $publisher = example::BookStore::Publisher->new({ name => "My Publisher", publisher_id => 27 });
-	my $author    = example::BookStore::Author->load({ author_id => 3 });
+	my $publisher = test::BookStore::Publisher->new({ name => "My Publisher", publisher_id => 27 });
+	my $author    = test::BookStore::Author->load({ author_id => 3 });
 	my $book      = $publisher->add_book({ author => $author, title => "My Book", isbn => "XYZ" });
 
 	# make sure that the parent property is being pulled directly from the parent object.
@@ -465,8 +465,8 @@ sub objectChildParent5 : Test(7)
 {
 	my $self = shift;
 
-	my $publisher = example::BookStore::Publisher->new({ name => "My Publisher", publisher_id => 27 });
-	my $author    = example::BookStore::Author->load({ author_id => 3 });
+	my $publisher = test::BookStore::Publisher->new({ name => "My Publisher", publisher_id => 27 });
+	my $author    = test::BookStore::Author->load({ author_id => 3 });
 	my $book      = $publisher->add_book({ author => $author, title => "My Book", isbn => "XYZ" });
 
 	my @books;
@@ -492,14 +492,14 @@ sub objectChildParent6 : Test(7)
 {
 	my $self = shift;
 
-	my $author = example::BookStore::Author->new({
+	my $author = test::BookStore::Author->new({
 		first_name => 'John B',
 		last_name  => 'Smith'
 	});
 
-	my $book = example::BookStore::Book->new({
+	my $book = test::BookStore::Book->new({
 		author    => $author,
-		publisher => example::BookStore::Publisher->load({ publisher_id => 1 }),
+		publisher => test::BookStore::Publisher->load({ publisher_id => 1 }),
 		title     => 'My Book',
 		isbn      => 'XYZ'
 	});
@@ -531,7 +531,7 @@ sub objectOrderBy1 : Test(1)
 
 	my $criteria = Xmldoom::Criteria->new();
 	$criteria->add_order_by_prop( 'Book/title' );
-	my @books = example::BookStore::Book->Search( $criteria );
+	my @books = test::BookStore::Book->Search( $criteria );
 
 	is ( $books[0]->get_title(), 'Life, the Universe and Everything' );
 }
@@ -542,7 +542,7 @@ sub objectOrderBy2 : Test(1)
 
 	my $criteria = Xmldoom::Criteria->new();
 	$criteria->add_order_by_attr( 'book/title' );
-	my @books = example::BookStore::Book->Search( $criteria );
+	my @books = test::BookStore::Book->Search( $criteria );
 
 	is ( $books[0]->get_title(), 'Life, the Universe and Everything' );
 }
@@ -551,7 +551,7 @@ sub objectXml1 : Test(1)
 {
 	my $self = shift;
 
-	my $book = example::BookStore::Book->load({ book_id => 1 });
+	my $book = test::BookStore::Book->load({ book_id => 1 });
 
 	my $generator;
 	$generator = Xmldoom::Object::XMLGenerator->new({ expand_objects => 0 });
@@ -581,7 +581,7 @@ sub objectXml2 : Test(1)
 {
 	my $self = shift;
 
-	my $book = example::BookStore::Book->load({ book_id => 1 });
+	my $book = test::BookStore::Book->load({ book_id => 1 });
 
 	my $generator;
 	$generator = Xmldoom::Object::XMLGenerator->new({ expand_objects => 1 });
@@ -618,7 +618,7 @@ sub objectCustomProperty : Test(1)
 {
 	my $self = shift;
 
-	my $book = example::BookStore::Book->load({ book_id => 1 });
+	my $book = test::BookStore::Book->load({ book_id => 1 });
 
 	is( $book->get_age(), 11 );
 }
@@ -627,7 +627,7 @@ sub objectComplexPropOptions1 : Test(1)
 {
 	my $self = shift;
 
-	my $book = example::BookStore::Book->load({ book_id => 1 });
+	my $book = test::BookStore::Book->load({ book_id => 1 });
 	my $publisher_id = $book->_get_property("publisher_id");
 
 	is( $publisher_id->get_pretty(), "Lulu Press" );
@@ -637,7 +637,7 @@ sub objectComplexPropOptions2 : Test(8)
 {
 	my $self = shift;
 
-	my $book = example::BookStore::Book->load({ book_id => 1 });
+	my $book = test::BookStore::Book->load({ book_id => 1 });
 	my $publisher_id = $book->_get_property("publisher_id");
 	my $data_type = $publisher_id->get_data_type({ include_options => 1 });
 	my $options = $data_type->{options};
@@ -658,7 +658,7 @@ sub objectComplexPropOptions3 : Test(1)
 
 	my $self = shift;
 
-	my $book = example::BookStore::Book->load({ book_id => 1 });
+	my $book = test::BookStore::Book->load({ book_id => 1 });
 	my $publisher = $book->_get_property("publisher");
 
 	is( $publisher->get_pretty(), "Lulu Press" );
@@ -668,7 +668,7 @@ sub objectComplexPropOptions4 : Test(8)
 {
 	my $self = shift;
 
-	my $book = example::BookStore::Book->load({ book_id => 1 });
+	my $book = test::BookStore::Book->load({ book_id => 1 });
 	my $publisher = $book->_get_property("publisher");
 	my $data_type = $publisher->get_data_type({ include_options => 1 });
 	my $options = $data_type->{options};
@@ -687,7 +687,7 @@ sub objectManyToManySimple1 : Test(4)
 {
 	my $self = shift;
 
-	my $order = example::BookStore::Order->load({ order_id => 1 });
+	my $order = test::BookStore::Order->load({ order_id => 1 });
 	my @books_ordered = $order->get_books_ordered();
 
 	is( $books_ordered[0]->get_book()->get_title(), "My Science Fiction Autobiography" );
@@ -700,7 +700,7 @@ sub objectManyToManyComplex1 : Test(2)
 {
 	my $self = shift;
 
-	my $order = example::BookStore::Order->load({ order_id => 1 });
+	my $order = test::BookStore::Order->load({ order_id => 1 });
 	my @books = $order->get_books();
 
 	is( $books[0]->get_title(), "My Science Fiction Autobiography" );
@@ -711,7 +711,7 @@ sub objectCustomIdGenerator : Test(1)
 {
 	my $self = shift;
 
-	my $publisher = example::BookStore::Publisher->new({
+	my $publisher = test::BookStore::Publisher->new({
 		name => "Mine Publisher"
 	});
 
@@ -724,7 +724,7 @@ sub objectGetAllProps : Test(5)
 {
 	my $self = shift;
 
-	my $book  = example::BookStore::Book->load({ book_id => 1 });
+	my $book  = test::BookStore::Book->load({ book_id => 1 });
 	my $props = $book->get();
 
 	is( $props->{title},                     "My Science Fiction Autobiography" );
@@ -746,7 +746,7 @@ sub objectCallback1 : Test(2)
 {
 	my $self = shift;
 
-	my $book = example::BookStore::Book->new();
+	my $book = test::BookStore::Book->new();
 
 	# register some random callback
 	my $cb = new Callback ($self, "objectCallback0", 'value2');
@@ -768,9 +768,9 @@ sub testDualConn1 : Test(8)
 {
 	my $self = shift;
 
-	my $test = example::BookStore::Test1->new();
-	$test->set_book1( example::BookStore::Book->load({ book_id => 1 }) );
-	$test->set_book2( example::BookStore::Book->load({ book_id => 2 }) );
+	my $test = test::BookStore::Test1->new();
+	$test->set_book1( test::BookStore::Book->load({ book_id => 1 }) );
+	$test->set_book2( test::BookStore::Book->load({ book_id => 2 }) );
 	
 	# check that the property sets worked correctly.
 	is( $test->_get_attr('book_id_1'), 1 );
@@ -782,7 +782,7 @@ sub testDualConn1 : Test(8)
 	is( $test->_get_attr('book_id_1'), 1 );
 	is( $test->_get_attr('book_id_2'), 2 );
 
-	my $test2 = example::BookStore::Test1->load({ id => 1 });
+	my $test2 = test::BookStore::Test1->load({ id => 1 });
 
 	# test loading the object from the database
 	is( $test2->_get_attr('book_id_1'), 1 );
@@ -797,7 +797,7 @@ sub testCopy : Test(2)
 {
 	my $self = shift;
 
-	my $book = example::BookStore::Book->load({ book_id => 1 });
+	my $book = test::BookStore::Book->load({ book_id => 1 });
 	my $book2 = $book->copy();
 	
 	is( $book2->get_title(), 'My Science Fiction Autobiography' );
@@ -811,7 +811,7 @@ sub testGetPropertyValue : Test(1)
 {
 	my $self = shift;
 
-	my $book = example::BookStore::Book->load({ book_id => 1 });
+	my $book = test::BookStore::Book->load({ book_id => 1 });
 	my $value = $book->_get_property_value( 'publisher/name' );
 
 	is( $value, 'Lulu Press' );
